Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // This error occurs when the token is expired. ErrExpiredToken = errors.New("token has expired") // This error occurs when the given token is invalid. ErrInvalidToken = errors.New("invalid token") )
Functions ¶
This section is empty.
Types ¶
type JWTMaker ¶
type JWTMaker struct {
// contains filtered or unexported fields
}
JWTMaker is a JavaScript Web Token Maker.
func (*JWTMaker) CreateToken ¶
type Maker ¶
type Maker interface {
// CreateToken creates a new token for a specific username and duration.
CreateToken(username string, duration time.Duration) (string, error)
// Veirfy token checks if the token is valid or not.
VerifyToken(token string) (*Payload, error)
}
Maker is an interface for managing tokens.
func NewJWTMaker ¶
NewJWTMaker creates a new JWTMaker.
func NewPasetoMaker ¶
type PasetoMaker ¶
type PasetoMaker struct {
// contains filtered or unexported fields
}
PasetoMaker is a PASETO token Maker.
func (*PasetoMaker) CreateToken ¶
func (*PasetoMaker) VerifyToken ¶
func (maker *PasetoMaker) VerifyToken(token string) (*Payload, error)
type Payload ¶
type Payload struct {
ID uuid.UUID `json:"id"`
Username string `json:"username"`
IssuedAt time.Time `json:"issued_at"`
ExpiredAt time.Time `json:"expired_at"`
}
Payload contains the payload data of the token
func NewPayload ¶
NewPayload creates a new token payload with a specific username and duration.
Click to show internal directories.
Click to hide internal directories.